You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@chemistry.apache.org by sk...@apache.org on 2010/05/05 10:40:32 UTC

svn commit: r941202 - in /incubator/chemistry/opencmis/trunk: chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apa...

Author: sklevenz
Date: Wed May  5 08:40:31 2010
New Revision: 941202

URL: http://svn.apache.org/viewvc?rev=941202&view=rev
Log:
Fix:

https://issues.apache.org/jira/browse/CMIS-200

Added:
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java   (contents, props changed)
      - copied, changed from r941171, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterable.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java   (contents, props changed)
      - copied, changed from r940876, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterator.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java   (contents, props changed)
      - copied, changed from r941171, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterable.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java   (contents, props changed)
      - copied, changed from r940876, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterator.java
Removed:
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterable.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterator.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterable.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterator.java
Modified:
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/CmisObject.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Folder.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ObjectType.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Session.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/AbstractPersistentCmisObject.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentFolderImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentSessionImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/DocumentTypeImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/FolderTypeImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/ObjectTypeHelper.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/PolicyTypeImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/RelationshipTypeImpl.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractIterator.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractPageFetch.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/CollectionIterable.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/test/java/org/apache/chemistry/opencmis/client/runtime/ItemIterableTest.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyDiscoverIT.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyNavigationIT.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyTypeIT.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectRelationIT.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectVersionIT.java
    incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/sample/AbstractSampleIT.java

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/CmisObject.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/CmisObject.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/CmisObject.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/CmisObject.java Wed May  5 08:40:31 2010
@@ -123,7 +123,7 @@ public interface CmisObject extends Obje
 
     // relationship service
 
-    PagingIterable<Relationship> getRelationships(boolean includeSubRelationshipTypes,
+    ItemIterable<Relationship> getRelationships(boolean includeSubRelationshipTypes,
             RelationshipDirection relationshipDirection, ObjectType type, OperationContext context);
 
     // renditions

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Folder.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Folder.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Folder.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Folder.java Wed May  5 08:40:31 2010
@@ -59,9 +59,9 @@ public interface Folder extends Fileable
 
     List<Tree<FileableCmisObject>> getDescendants(int depth, OperationContext context);
 
-    PagingIterable<CmisObject> getChildren();
+    ItemIterable<CmisObject> getChildren();
 
-    PagingIterable<CmisObject> getChildren(OperationContext context);
+    ItemIterable<CmisObject> getChildren(OperationContext context);
 
     boolean isRootFolder();
 
@@ -72,9 +72,9 @@ public interface Folder extends Fileable
     /**
      * Returns all checked out documents of this folder.
      */
-    PagingIterable<Document> getCheckedOutDocs();
+    ItemIterable<Document> getCheckedOutDocs();
 
-    PagingIterable<Document> getCheckedOutDocs(OperationContext context);
+    ItemIterable<Document> getCheckedOutDocs(OperationContext context);
 
     // folder specific properties
 

Copied: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java (from r941171, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterable.java)
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java?p2=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java&p1=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterable.java&r1=941171&r2=941202&rev=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterable.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java Wed May  5 08:40:31 2010
@@ -20,11 +20,11 @@ package org.apache.chemistry.opencmis.cl
 
 /**
  * Iterable for CMIS collections that allows ability to skip to specific
- * position.
+ * position or return a sub collection.
  * 
  * @param <T>
  */
-public interface PagingIterable<T> extends Iterable<T> {
+public interface ItemIterable<T> extends Iterable<T> {
 
     /**
      * Skip to position within CMIS collection
@@ -32,30 +32,30 @@ public interface PagingIterable<T> exten
      * @param position
      * @return iterable whose starting point is the specified skip to position
      */
-    PagingIterable<T> skipTo(long position);
+    ItemIterable<T> skipTo(long position);
 
     /**
-     * Gets an iterable for the current page within the CMIS collection using
-     * default page size
+     * Gets an iterable for the current sub collection within the CMIS collection using
+     * default maximum number of items 
      * 
      * @return iterable for current page
      */
-    PagingIterable<T> getPage();
+    ItemIterable<T> getPage();
 
     /**
-     * Gets an iterable for the current page within the CMIS collection
+     * Gets an iterable for the current sub collection within the CMIS collection
      * 
      * @param maxNumItems
-     *            maximum number of items the page will contain
+     *            maximum number of items the sub collection will contain
      * 
      * @return iterable for current page
      */
-    PagingIterable<T> getPage(int maxNumItems);
+    ItemIterable<T> getPage(int maxNumItems);
 
     /*
      * (non-Javadoc)
      * 
      * @see java.lang.Iterable#iterator()
      */
-    PagingIterator<T> iterator();
+    ItemIterator<T> iterator();
 }

Propchange: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterable.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java (from r940876, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterator.java)
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java?p2=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java&p1=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterator.java&r1=940876&r2=941202&rev=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ObjectType.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ObjectType.java Wed May  5 08:40:31 2010
@@ -70,7 +70,7 @@ public interface ObjectType extends Type
      * @return a {@code List} of types which are directly derived from this
      *         type. @
      */
-    PagingIterable<ObjectType> getChildren();
+    ItemIterable<ObjectType> getChildren();
 
     /**
      * Get the list of all types somehow derived from this type.

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Session.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Session.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Session.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/Session.java Wed May  5 08:40:31 2010
@@ -123,7 +123,7 @@ public interface Session {
     /**
      * Returns the type children of the given type id.
      */
-    PagingIterable<ObjectType> getTypeChildren(String typeId, boolean includePropertyDefinitions);
+    ItemIterable<ObjectType> getTypeChildren(String typeId, boolean includePropertyDefinitions);
 
     /**
      * Returns the type descendants of the given type id.
@@ -144,9 +144,9 @@ public interface Session {
      * 
      * @see Folder#getCheckedOutDocs(int)
      */
-    PagingIterable<Document> getCheckedOutDocs();
+    ItemIterable<Document> getCheckedOutDocs();
 
-    PagingIterable<Document> getCheckedOutDocs(OperationContext context);
+    ItemIterable<Document> getCheckedOutDocs(OperationContext context);
 
     /**
      * Object service <code>getObject</code>.
@@ -167,14 +167,14 @@ public interface Session {
     /**
      * Discovery service <code>query</code>.
      */
-    PagingIterable<QueryResult> query(String statement, boolean searchAllVersions);
+    ItemIterable<QueryResult> query(String statement, boolean searchAllVersions);
 
-    PagingIterable<QueryResult> query(String statement, boolean searchAllVersions, OperationContext context);
+    ItemIterable<QueryResult> query(String statement, boolean searchAllVersions, OperationContext context);
 
     /**
      * Discovery service <code>getContentChanges</code>.
      */
-    PagingIterable<ChangeEvent> getContentChanges(String changeLogToken);
+    ItemIterable<ChangeEvent> getContentChanges(String changeLogToken);
 
     // create
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/AbstractPersistentCmisObject.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/AbstractPersistentCmisObject.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/AbstractPersistentCmisObject.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/AbstractPersistentCmisObject.java Wed May  5 08:40:31 2010
@@ -34,7 +34,7 @@ import org.apache.chemistry.opencmis.cli
 import org.apache.chemistry.opencmis.client.api.ObjectId;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
 import org.apache.chemistry.opencmis.client.api.OperationContext;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Policy;
 import org.apache.chemistry.opencmis.client.api.Property;
 import org.apache.chemistry.opencmis.client.api.Relationship;
@@ -726,7 +726,7 @@ public abstract class AbstractPersistent
      * org.apache.opencmis.client.api.objecttype.ObjectType,
      * org.apache.opencmis.client.api.OperationContext, int)
      */
-    public PagingIterable<Relationship> getRelationships(final boolean includeSubRelationshipTypes,
+    public ItemIterable<Relationship> getRelationships(final boolean includeSubRelationshipTypes,
             final RelationshipDirection relationshipDirection, ObjectType type, OperationContext context) {
 
         final String objectId = getObjectId();
@@ -742,7 +742,7 @@ public abstract class AbstractPersistent
                 // fetch the relationships
                 ObjectList relList = relationshipService.getObjectRelationships(getRepositoryId(), objectId,
                         includeSubRelationshipTypes, relationshipDirection, typeId, ctxt.getFilterString(), ctxt
-                                .isIncludeAllowableActions(), BigInteger.valueOf(this.pageSize), BigInteger
+                                .isIncludeAllowableActions(), BigInteger.valueOf(this.maxNumItems), BigInteger
                                 .valueOf(skipCount), null);
 
                 // convert relationship objects

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentFolderImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentFolderImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentFolderImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentFolderImpl.java Wed May  5 08:40:31 2010
@@ -34,7 +34,7 @@ import org.apache.chemistry.opencmis.cli
 import org.apache.chemistry.opencmis.client.api.ObjectId;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
 import org.apache.chemistry.opencmis.client.api.OperationContext;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Policy;
 import org.apache.chemistry.opencmis.client.api.Tree;
 import org.apache.chemistry.opencmis.client.runtime.util.AbstractPageFetch;
@@ -273,7 +273,7 @@ public class PersistentFolderImpl extend
      * 
      * @see org.apache.opencmis.client.api.Folder#getCheckedOutDocs(int)
      */
-    public PagingIterable<Document> getCheckedOutDocs() {
+    public ItemIterable<Document> getCheckedOutDocs() {
         return getCheckedOutDocs(getSession().getDefaultContext());
     }
 
@@ -283,7 +283,7 @@ public class PersistentFolderImpl extend
      * @seeorg.apache.opencmis.client.api.Folder#getCheckedOutDocs(org.apache.
      * opencmis.client.api. OperationContext, int)
      */
-    public PagingIterable<Document> getCheckedOutDocs(OperationContext context) {
+    public ItemIterable<Document> getCheckedOutDocs(OperationContext context) {
         final String objectId = getObjectId();
         final NavigationService navigationService = getBinding().getNavigationService();
         final ObjectFactory objectFactory = getSession().getObjectFactory();
@@ -297,7 +297,7 @@ public class PersistentFolderImpl extend
                 // get checked out documents for this folder
                 ObjectList checkedOutDocs = navigationService.getCheckedOutDocs(getRepositoryId(), objectId, ctxt
                         .getFilterString(), ctxt.getOrderBy(), ctxt.isIncludeAllowableActions(), ctxt
-                        .getIncludeRelationships(), ctxt.getRenditionFilterString(), BigInteger.valueOf(this.pageSize),
+                        .getIncludeRelationships(), ctxt.getRenditionFilterString(), BigInteger.valueOf(this.maxNumItems),
                         BigInteger.valueOf(skipCount), null);
 
                 // convert objects
@@ -326,7 +326,7 @@ public class PersistentFolderImpl extend
      * 
      * @see org.apache.opencmis.client.api.Folder#getChildren(int)
      */
-    public PagingIterable<CmisObject> getChildren() {
+    public ItemIterable<CmisObject> getChildren() {
         return getChildren(getSession().getDefaultContext());
     }
 
@@ -337,7 +337,7 @@ public class PersistentFolderImpl extend
      * org.apache.opencmis.client.api.Folder#getChildren(org.apache.opencmis
      * .client.api.OperationContext , int)
      */
-    public PagingIterable<CmisObject> getChildren(OperationContext context) {
+    public ItemIterable<CmisObject> getChildren(OperationContext context) {
         final String objectId = getObjectId();
         final NavigationService navigationService = getBinding().getNavigationService();
         final ObjectFactory objectFactory = getSession().getObjectFactory();
@@ -352,7 +352,7 @@ public class PersistentFolderImpl extend
                 ObjectInFolderList children = navigationService.getChildren(getRepositoryId(), objectId, ctxt
                         .getFilterString(), ctxt.getOrderBy(), ctxt.isIncludeAllowableActions(), ctxt
                         .getIncludeRelationships(), ctxt.getRenditionFilterString(), ctxt.isIncludePathSegments(),
-                        BigInteger.valueOf(this.pageSize), BigInteger.valueOf(skipCount), null);
+                        BigInteger.valueOf(this.maxNumItems), BigInteger.valueOf(skipCount), null);
 
                 // convert objects
                 List<CmisObject> page = new ArrayList<CmisObject>();

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentSessionImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentSessionImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentSessionImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/PersistentSessionImpl.java Wed May  5 08:40:31 2010
@@ -37,7 +37,7 @@ import org.apache.chemistry.opencmis.cli
 import org.apache.chemistry.opencmis.client.api.ObjectId;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
 import org.apache.chemistry.opencmis.client.api.OperationContext;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Policy;
 import org.apache.chemistry.opencmis.client.api.QueryResult;
 import org.apache.chemistry.opencmis.client.api.Session;
@@ -234,7 +234,7 @@ public class PersistentSessionImpl imple
      * 
      * @see org.apache.opencmis.client.api.Session#getCheckedOutDocs(int)
      */
-    public PagingIterable<Document> getCheckedOutDocs() {
+    public ItemIterable<Document> getCheckedOutDocs() {
         return getCheckedOutDocs(getDefaultContext());
     }
 
@@ -244,7 +244,7 @@ public class PersistentSessionImpl imple
      * @seeorg.apache.opencmis.client.api.Session#getCheckedOutDocs(org.apache.
      * opencmis.client.api. OperationContext, int)
      */
-    public PagingIterable<Document> getCheckedOutDocs(OperationContext context) {
+    public ItemIterable<Document> getCheckedOutDocs(OperationContext context) {
         final NavigationService navigationService = getBinding().getNavigationService();
         final ObjectFactory objectFactory = getObjectFactory();
         final OperationContext ctxt = new OperationContextImpl(context);
@@ -257,8 +257,8 @@ public class PersistentSessionImpl imple
                 // get all checked out documents
                 ObjectList checkedOutDocs = navigationService.getCheckedOutDocs(getRepositoryId(), null, ctxt
                         .getFilterString(), ctxt.getOrderBy(), ctxt.isIncludeAllowableActions(), ctxt
-                        .getIncludeRelationships(), ctxt.getRenditionFilterString(), BigInteger.valueOf(this.pageSize),
-                        BigInteger.valueOf(skipCount), null);
+                        .getIncludeRelationships(), ctxt.getRenditionFilterString(), BigInteger
+                        .valueOf(this.maxNumItems), BigInteger.valueOf(skipCount), null);
 
                 // convert objects
                 List<Document> page = new ArrayList<Document>();
@@ -288,7 +288,7 @@ public class PersistentSessionImpl imple
      * org.apache.opencmis.client.api.Session#getContentChanges(java.lang.String
      * , int)
      */
-    public PagingIterable<ChangeEvent> getContentChanges(String changeLogToken) {
+    public ItemIterable<ChangeEvent> getContentChanges(String changeLogToken) {
         throw new CmisRuntimeException("not implemented");
     }
 
@@ -486,6 +486,7 @@ public class PersistentSessionImpl imple
      * 
      * 
      * 
+     * 
      * @seeorg.apache.opencmis.client.api.Session#getRootFolder(org.apache.opencmis
      * .client.api. OperationContext)
      */
@@ -507,11 +508,12 @@ public class PersistentSessionImpl imple
      * org.apache.opencmis.client.api.Session#getTypeChildren(java.lang.String,
      * boolean, int)
      */
-    public PagingIterable<ObjectType> getTypeChildren(final String typeId, final boolean includePropertyDefinitions) {
+    public ItemIterable<ObjectType> getTypeChildren(final String typeId, final boolean includePropertyDefinitions) {
         final RepositoryService repositoryService = getBinding().getRepositoryService();
         final ObjectFactory objectFactory = this.getObjectFactory();
 
-        return new CollectionIterable<ObjectType>(new AbstractPageFetch<ObjectType>(this.getDefaultContext().getMaxItemsPerPage()) {
+        return new CollectionIterable<ObjectType>(new AbstractPageFetch<ObjectType>(this.getDefaultContext()
+                .getMaxItemsPerPage()) {
 
             @Override
             protected AbstractPageFetch.PageFetchResult<ObjectType> fetchPage(long skipCount) {
@@ -519,7 +521,7 @@ public class PersistentSessionImpl imple
                 // fetch the data
                 TypeDefinitionList tdl = repositoryService.getTypeChildren(
                         PersistentSessionImpl.this.getRepositoryId(), typeId, includePropertyDefinitions, BigInteger
-                                .valueOf(this.pageSize), BigInteger.valueOf(skipCount), null);
+                                .valueOf(this.maxNumItems), BigInteger.valueOf(skipCount), null);
 
                 // convert type definitions
                 List<ObjectType> page = new ArrayList<ObjectType>(tdl.getList().size());
@@ -583,7 +585,7 @@ public class PersistentSessionImpl imple
      * @see org.apache.opencmis.client.api.Session#query(java.lang.String,
      * boolean, int)
      */
-    public PagingIterable<QueryResult> query(final String statement, final boolean searchAllVersions) {
+    public ItemIterable<QueryResult> query(final String statement, final boolean searchAllVersions) {
         return query(statement, searchAllVersions, getDefaultContext());
     }
 
@@ -593,7 +595,7 @@ public class PersistentSessionImpl imple
      * @see org.apache.opencmis.client.api.Session#query(java.lang.String,
      * boolean, org.apache.opencmis.client.api.OperationContext, int)
      */
-    public PagingIterable<QueryResult> query(final String statement, final boolean searchAllVersions,
+    public ItemIterable<QueryResult> query(final String statement, final boolean searchAllVersions,
             OperationContext context) {
 
         final DiscoveryService discoveryService = getBinding().getDiscoveryService();
@@ -608,7 +610,7 @@ public class PersistentSessionImpl imple
                 // fetch the data
                 ObjectList resultList = discoveryService.query(getRepositoryId(), statement, searchAllVersions, ctxt
                         .isIncludeAllowableActions(), ctxt.getIncludeRelationships(), ctxt.getRenditionFilterString(),
-                        BigInteger.valueOf(this.pageSize), BigInteger.valueOf(skipCount), null);
+                        BigInteger.valueOf(this.maxNumItems), BigInteger.valueOf(skipCount), null);
 
                 // convert type definitions
                 List<QueryResult> page = new ArrayList<QueryResult>();

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/DocumentTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/DocumentTypeImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/DocumentTypeImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/DocumentTypeImpl.java Wed May  5 08:40:31 2010
@@ -22,7 +22,7 @@ import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.DocumentType;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
 import org.apache.chemistry.opencmis.commons.api.DocumentTypeDefinition;
@@ -46,7 +46,7 @@ public class DocumentTypeImpl extends Do
         return helper.getBaseType();
     }
 
-    public PagingIterable<ObjectType> getChildren() {
+    public ItemIterable<ObjectType> getChildren() {
         return helper.getChildren();
     }
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/FolderTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/FolderTypeImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/FolderTypeImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/FolderTypeImpl.java Wed May  5 08:40:31 2010
@@ -22,7 +22,7 @@ import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.FolderType;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
 import org.apache.chemistry.opencmis.commons.api.FolderTypeDefinition;
@@ -46,7 +46,7 @@ public class FolderTypeImpl extends Fold
         return helper.getBaseType();
     }
 
-    public PagingIterable<ObjectType> getChildren() {
+    public ItemIterable<ObjectType> getChildren() {
         return helper.getChildren();
     }
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/ObjectTypeHelper.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/ObjectTypeHelper.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/ObjectTypeHelper.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/ObjectTypeHelper.java Wed May  5 08:40:31 2010
@@ -21,7 +21,7 @@ package org.apache.chemistry.opencmis.cl
 import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
 
@@ -75,7 +75,7 @@ public class ObjectTypeHelper {
         return parentType;
     }
 
-    public PagingIterable<ObjectType> getChildren() {
+    public ItemIterable<ObjectType> getChildren() {
         return session.getTypeChildren(objectType.getId(), true);
     }
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/PolicyTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/PolicyTypeImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/PolicyTypeImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/PolicyTypeImpl.java Wed May  5 08:40:31 2010
@@ -21,7 +21,7 @@ package org.apache.chemistry.opencmis.cl
 import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.PolicyType;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
@@ -46,7 +46,7 @@ public class PolicyTypeImpl extends Poli
         return helper.getBaseType();
     }
 
-    public PagingIterable<ObjectType> getChildren() {
+    public ItemIterable<ObjectType> getChildren() {
         return helper.getChildren();
     }
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/RelationshipTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/RelationshipTypeImpl.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/RelationshipTypeImpl.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/objecttype/RelationshipTypeImpl.java Wed May  5 08:40:31 2010
@@ -22,7 +22,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.RelationshipType;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
@@ -49,7 +49,7 @@ public class RelationshipTypeImpl extend
         return helper.getBaseType();
     }
 
-    public PagingIterable<ObjectType> getChildren() {
+    public ItemIterable<ObjectType> getChildren() {
         return helper.getChildren();
     }
 

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractIterator.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractIterator.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractIterator.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractIterator.java Wed May  5 08:40:31 2010
@@ -20,16 +20,16 @@ package org.apache.chemistry.opencmis.cl
 
 import java.util.List;
 
-import org.apache.chemistry.opencmis.client.api.PagingIterator;
+import org.apache.chemistry.opencmis.client.api.ItemIterator;
 import org.apache.chemistry.opencmis.client.runtime.util.AbstractPageFetch.PageFetchResult;
 
 
 /**
- * Abstract <code>PagingIterator</code> implementation.
+ * Abstract <code>ItemIterator</code> implementation.
  * 
  * @param <T>
  */
-public abstract class AbstractIterator<T> implements PagingIterator<T> {
+public abstract class AbstractIterator<T> implements ItemIterator<T> {
 
     private long skipCount;
     private int skipOffset;
@@ -62,9 +62,9 @@ public abstract class AbstractIterator<T
 
     /*
      * (non-Javadoc)
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterator#getPageNumItems()
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterator#getPageNumItems()
      */
-    public long getPageNumItems() {
+    public long getCurrentCollectionNumItems() {
         PageFetchResult<T> page = getCurrentPage();
         if (page != null) {
             List<T> items = page.getPage();
@@ -77,7 +77,7 @@ public abstract class AbstractIterator<T
     
     /*
      * (non-Javadoc)
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterator#getTotalNumItems()
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterator#getTotalNumItems()
      */
     public long getTotalNumItems() {
         if (totalItems == null) {
@@ -95,7 +95,7 @@ public abstract class AbstractIterator<T
     
     /*
      * (non-Javadoc)
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterator#getHasMoreItems()
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterator#getHasMoreItems()
      */
     public boolean getHasMoreItems() {
         if (hasMoreItems == null) {

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractPageFetch.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractPageFetch.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractPageFetch.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/AbstractPageFetch.java Wed May  5 08:40:31 2010
@@ -28,10 +28,10 @@ import java.util.List;
  */
 public abstract class AbstractPageFetch<T> {
 
-    protected long pageSize;
+    protected long maxNumItems;
 
-    public AbstractPageFetch(long pageSize) {
-        this.pageSize = pageSize;
+    public AbstractPageFetch(long maxNumItems) {
+        this.maxNumItems = maxNumItems;
     }
     
     /**
@@ -68,8 +68,8 @@ public abstract class AbstractPageFetch<
         }
     }
 
-    public void setPageSize(int maxNumItems) {
-        this.pageSize = maxNumItems;
+    public void setMaxNumItems(int maxNumItems) {
+        this.maxNumItems = maxNumItems;
     }
 
 }

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/CollectionIterable.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/CollectionIterable.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/CollectionIterable.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/CollectionIterable.java Wed May  5 08:40:31 2010
@@ -18,13 +18,13 @@
  */
 package org.apache.chemistry.opencmis.client.runtime.util;
 
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
-import org.apache.chemistry.opencmis.client.api.PagingIterator;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterator;
 
 /**
  * CMIS Collection Iterable
  */
-public class CollectionIterable<T> implements PagingIterable<T> {
+public class CollectionIterable<T> implements ItemIterable<T> {
 
     private AbstractPageFetch<T> pageFetch;
     private long skipCount;
@@ -54,7 +54,7 @@ public class CollectionIterable<T> imple
      * 
      * @see java.lang.Iterable#iterator()
      */
-    public PagingIterator<T> iterator() {
+    public ItemIterator<T> iterator() {
         return new CollectionIterator<T>(skipCount, pageFetch);
     }
 
@@ -63,26 +63,26 @@ public class CollectionIterable<T> imple
      * 
      * @see org.apache.chemistry.opencmis.client.api.util.PagingIterable#skipTo(long)
      */
-    public PagingIterable<T> skipTo(long position) {
+    public ItemIterable<T> skipTo(long position) {
         return new CollectionIterable<T>(position, pageFetch);
     }
 
     /*
      * (non-Javadoc)
      * 
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterable#getPage()
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterable#getPage()
      */
-    public PagingIterable<T> getPage() {
-        return new PageIterable<T>(skipCount, pageFetch);
+    public ItemIterable<T> getPage() {
+        return new ItemIterableImpl<T>(skipCount, pageFetch);
     }
 
     /*
      * (non-Javadoc)
      * 
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterable#getPage(int)
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterable#getPage(int)
      */
-    public PagingIterable<T> getPage(int maxNumItems) {
-        this.pageFetch.setPageSize(maxNumItems);
-        return new PageIterable<T>(skipCount, pageFetch);
+    public ItemIterable<T> getPage(int maxNumItems) {
+        this.pageFetch.setMaxNumItems(maxNumItems);
+        return new ItemIterableImpl<T>(skipCount, pageFetch);
    }
 }

Copied: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java (from r941171, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterable.java)
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java?p2=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java&p1=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterable.java&r1=941171&r2=941202&rev=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterable.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java Wed May  5 08:40:31 2010
@@ -18,13 +18,13 @@
  */
 package org.apache.chemistry.opencmis.client.runtime.util;
 
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
-import org.apache.chemistry.opencmis.client.api.PagingIterator;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterator;
 
 /**
  * Iterable for a CMIS Collection Page
  */
-public class PageIterable<T> implements PagingIterable<T> {
+public class ItemIterableImpl<T> implements ItemIterable<T> {
 
     private AbstractPageFetch<T> pageFetch;
     private long skipCount;
@@ -34,7 +34,7 @@ public class PageIterable<T> implements 
      * 
      * @param pageFetch
      */
-    public PageIterable(AbstractPageFetch<T> pageFetch) {
+    public ItemIterableImpl(AbstractPageFetch<T> pageFetch) {
         this(0, pageFetch);
     }
 
@@ -44,7 +44,7 @@ public class PageIterable<T> implements 
      * @param position
      * @param pageFetch
      */
-    protected PageIterable(long position, AbstractPageFetch<T> pageFetch) {
+    protected ItemIterableImpl(long position, AbstractPageFetch<T> pageFetch) {
         this.pageFetch = pageFetch;
         this.skipCount = position;
     }
@@ -54,8 +54,8 @@ public class PageIterable<T> implements 
      * 
      * @see java.lang.Iterable#iterator()
      */
-    public PagingIterator<T> iterator() {
-        return new PageIterator<T>(skipCount, pageFetch);
+    public ItemIterator<T> iterator() {
+        return new ItemIteratorImpl<T>(skipCount, pageFetch);
     }
 
     /*
@@ -64,25 +64,26 @@ public class PageIterable<T> implements 
      * @see
      * org.apache.chemistry.opencmis.client.api.util.PagingIterable#skipTo(long)
      */
-    public PagingIterable<T> skipTo(long position) {
+    public ItemIterable<T> skipTo(long position) {
         return new CollectionIterable<T>(position, pageFetch);
     }
 
     /*
      * (non-Javadoc)
      * 
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterable#getPage()
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterable#getPage()
      */
-    public PagingIterable<T> getPage() {
-        return new PageIterable<T>(skipCount, pageFetch);
+    public ItemIterable<T> getPage() {
+        return new ItemIterableImpl<T>(skipCount, pageFetch);
     }
 
     /*
      * (non-Javadoc)
      * 
-     * @see org.apache.chemistry.opencmis.client.api.PagingIterable#getPage(int)
+     * @see org.apache.chemistry.opencmis.client.api.ItemIterable#getPage(int)
      */
-    public PagingIterable<T> getPage(int maxNumItems) {
-        return new PageIterable<T>(skipCount, pageFetch);
+    public ItemIterable<T> getPage(int maxNumItems) {
+        this.pageFetch.setMaxNumItems(maxNumItems);
+        return new ItemIterableImpl<T>(skipCount, pageFetch);
     }
 }

Propchange: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIterableImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java (from r940876, incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterator.java)
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java?p2=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java&p1=incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterator.java&r1=940876&r2=941202&rev=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/PageIterator.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java Wed May  5 08:40:31 2010
@@ -27,7 +27,7 @@ import org.apache.chemistry.opencmis.cli
  * 
  * @param <T>
  */
-public class PageIterator<T> extends AbstractIterator<T> {
+public class ItemIteratorImpl<T> extends AbstractIterator<T> {
 
     /**
      * Construct
@@ -35,7 +35,7 @@ public class PageIterator<T> extends Abs
      * @param skipCount
      * @param pageFetch
      */
-    public PageIterator(long skipCount, AbstractPageFetch<T> pageFetch) {
+    public ItemIteratorImpl(long skipCount, AbstractPageFetch<T> pageFetch) {
         super(skipCount, pageFetch);
     }
 

Propchange: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/main/java/org/apache/chemistry/opencmis/client/runtime/util/ItemIteratorImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/test/java/org/apache/chemistry/opencmis/client/runtime/ItemIterableTest.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/test/java/org/apache/chemistry/opencmis/client/runtime/ItemIterableTest.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/test/java/org/apache/chemistry/opencmis/client/runtime/ItemIterableTest.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-impl/src/test/java/org/apache/chemistry/opencmis/client/runtime/ItemIterableTest.java Wed May  5 08:40:31 2010
@@ -28,8 +28,8 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
 
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
-import org.apache.chemistry.opencmis.client.api.PagingIterator;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterator;
 import org.apache.chemistry.opencmis.client.runtime.util.AbstractPageFetch;
 import org.apache.chemistry.opencmis.client.runtime.util.CollectionIterable;
 import org.apache.commons.logging.Log;
@@ -54,7 +54,7 @@ public class ItemIterableTest {
     private String[] data1 = { "A0" };
     private String[] data0 = {};
 
-    private PagingIterable<String> getIterable(final String[] data, long pageSize) {
+    private ItemIterable<String> getIterable(final String[] data, long pageSize) {
         return new CollectionIterable<String>(new AbstractPageFetch<String>(pageSize) {
 
             @Override
@@ -62,10 +62,10 @@ public class ItemIterableTest {
                 Boolean hasMoreItems = Boolean.TRUE;
                 List<String> page = new ArrayList<String>();
 
-                ItemIterableTest.log.info("(" + skipCount + "|" + this.pageSize + ") ");
+                ItemIterableTest.log.info("(" + skipCount + "|" + this.maxNumItems + ") ");
 
                 int from = (int) skipCount;
-                int to = (int) (skipCount + this.pageSize);
+                int to = (int) (skipCount + this.maxNumItems);
 
                 if (to >= data.length) {
                     to = data.length;
@@ -97,7 +97,7 @@ public class ItemIterableTest {
 
         this.loopAll(this.data10, 2);
         this.loopAll(this.data10, 1);
-        // this.loopAll(0); pageSize must be > 0
+        // this.loopAll(0); maxNumItems must be > 0
 
         this.loopAll(this.data1, 1);
         this.loopAll(this.data1, 5);
@@ -178,9 +178,9 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("totalNumItems");
 
         int pageSize = 5;
-        PagingIterable<String> p = this.getIterable(this.data10, pageSize);
+        ItemIterable<String> p = this.getIterable(this.data10, pageSize);
         assertNotNull(p);
-        PagingIterator<String> i = (PagingIterator<String>) p.iterator();
+        ItemIterator<String> i = (ItemIterator<String>) p.iterator();
         assertNotNull(i);
         assertEquals(pageSize + 1, i.getTotalNumItems());
         for (int idx = 0; i.hasNext() && idx < (pageSize + 1); idx++) {
@@ -195,9 +195,9 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("totalHasMoreItems");
 
         int pageSize = 5;
-        PagingIterable<String> p = this.getIterable(this.data10, pageSize);
+        ItemIterable<String> p = this.getIterable(this.data10, pageSize);
         assertNotNull(p);
-        PagingIterator<String> i = (PagingIterator<String>) p.iterator();
+        ItemIterator<String> i = (ItemIterator<String>) p.iterator();
         assertNotNull(i);
         assertEquals(true, i.getHasMoreItems());
         for (int idx = 0; i.hasNext() && idx < (pageSize + 1); idx++) {
@@ -212,27 +212,27 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("totalPageNumItems");
 
         int pageSize = 7;
-        PagingIterable<String> p = this.getIterable(this.data10, pageSize);
+        ItemIterable<String> p = this.getIterable(this.data10, pageSize);
         assertNotNull(p);
-        PagingIterator<String> i = (PagingIterator<String>) p.iterator();
+        ItemIterator<String> i = (ItemIterator<String>) p.iterator();
         assertNotNull(i);
-        assertEquals(pageSize, i.getPageNumItems());
+        assertEquals(pageSize, i.getCurrentCollectionNumItems());
         for (int idx = 0; i.hasNext() && idx < (pageSize + 1); idx++) {
             i.next();
         }
         assertEquals(pageSize + 1, i.getPosition());
-        assertEquals(this.data10.length - pageSize, i.getPageNumItems());
+        assertEquals(this.data10.length - pageSize, i.getCurrentCollectionNumItems());
     }
 
     private void loopSubPage(String[] data, int skipCount, int maxItems, int pageSize) {
         ItemIterableTest.log.info("loopSubPage (" + skipCount + ", " + maxItems + ", " + pageSize + ")");
         String msg = "";
 
-        PagingIterable<String> p = this.getIterable(data, pageSize);
+        ItemIterable<String> p = this.getIterable(data, pageSize);
         assertNotNull(p);
-        PagingIterable<String> pp = p.skipTo(skipCount);
+        ItemIterable<String> pp = p.skipTo(skipCount);
         assertNotNull(pp);
-        PagingIterable<String> ppp = pp.getPage(maxItems);
+        ItemIterable<String> ppp = pp.getPage(maxItems);
         assertNotNull(ppp);
 
         int count = 0;
@@ -250,9 +250,9 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("loopSkip (" + skipCount + ", " + pageSize + ")");
         String msg = "";
 
-        PagingIterable<String> p = this.getIterable(data, pageSize);
+        ItemIterable<String> p = this.getIterable(data, pageSize);
         assertNotNull(p);
-        PagingIterable<String> pp = p.skipTo(skipCount);
+        ItemIterable<String> pp = p.skipTo(skipCount);
         assertNotNull(pp);
 
         int count = 0;
@@ -270,7 +270,7 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("loopAll (" + pageSize + ")");
         String msg = "";
 
-        PagingIterable<String> p = this.getIterable(data, pageSize);
+        ItemIterable<String> p = this.getIterable(data, pageSize);
         assertNotNull(p);
 
         int count = 0;
@@ -288,9 +288,9 @@ public class ItemIterableTest {
         ItemIterableTest.log.info("loopPage (" + skipCount + ", " + pageSize + ")");
         String msg = "";
 
-        PagingIterable<String> p = this.getIterable(data, pageSize);
+        ItemIterable<String> p = this.getIterable(data, pageSize);
         assertNotNull(p);
-        PagingIterable<String> pp = p.skipTo(skipCount).getPage();
+        ItemIterable<String> pp = p.skipTo(skipCount).getPage();
         assertNotNull(pp);
 
         int count = 0;

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyDiscoverIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyDiscoverIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyDiscoverIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyDiscoverIT.java Wed May  5 08:40:31 2010
@@ -18,7 +18,7 @@
  */
 package org.apache.chemistry.opencmis.fit.runtime;
 
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.QueryResult;
 import org.apache.chemistry.opencmis.commons.enums.CapabilityChanges;
 import org.apache.chemistry.opencmis.commons.enums.CapabilityQuery;
@@ -40,7 +40,7 @@ public class ReadOnlyDiscoverIT extends 
             ReadOnlyDiscoverIT.log.info("queries not supported");
             break;
         default:
-            PagingIterable<QueryResult> resultSet = this.session.query(FixtureData.QUERY.toString(), false);
+            ItemIterable<QueryResult> resultSet = this.session.query(FixtureData.QUERY.toString(), false);
             Assert.assertNotNull(resultSet);
             // Assert.assertFalse(resultSet.isEmpty());
             for (QueryResult o : resultSet) {
@@ -60,7 +60,7 @@ public class ReadOnlyDiscoverIT extends 
             ReadOnlyDiscoverIT.log.info("queries not supported");
             break;
         default:
-            PagingIterable<QueryResult> resultSet = this.session.query(FixtureData.QUERY.toString(), false).skipTo(2).getPage(2);
+            ItemIterable<QueryResult> resultSet = this.session.query(FixtureData.QUERY.toString(), false).skipTo(2).getPage(2);
             Assert.assertNotNull(resultSet);
             // Assert.assertFalse(resultSet.isEmpty());
             for (QueryResult o : resultSet) {

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyNavigationIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyNavigationIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyNavigationIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyNavigationIT.java Wed May  5 08:40:31 2010
@@ -25,7 +25,7 @@ import junit.framework.Assert;
 import org.apache.chemistry.opencmis.client.api.CmisObject;
 import org.apache.chemistry.opencmis.client.api.FileableCmisObject;
 import org.apache.chemistry.opencmis.client.api.Folder;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Tree;
 import org.junit.Test;
 
@@ -37,7 +37,7 @@ public class ReadOnlyNavigationIT extend
         Folder folder = (Folder) this.session.getObjectByPath(path);
         Assert.assertNotNull("folder not found: " + path, folder);
 
-        PagingIterable<CmisObject> pl = folder.getChildren().skipTo(2).getPage(2);
+        ItemIterable<CmisObject> pl = folder.getChildren().skipTo(2).getPage(2);
         Assert.assertNotNull(pl);
 
         for (CmisObject o : pl) {
@@ -51,7 +51,7 @@ public class ReadOnlyNavigationIT extend
         Folder folder = (Folder) this.session.getObjectByPath(path);
         Assert.assertNotNull("folder not found: " + path, folder);
 
-        PagingIterable<CmisObject> pl = folder.getChildren();
+        ItemIterable<CmisObject> pl = folder.getChildren();
         Assert.assertNotNull(pl);
 
         for (CmisObject o : pl) {
@@ -66,7 +66,7 @@ public class ReadOnlyNavigationIT extend
         Assert.assertNotNull("folder not found: " + path, folder);
 
         this.session.getDefaultContext().setMaxItemsPerPage(1000);
-        PagingIterable<CmisObject> pl = folder.getChildren();
+        ItemIterable<CmisObject> pl = folder.getChildren();
         Assert.assertNotNull(pl);
 
         for (CmisObject o : pl) {
@@ -81,7 +81,7 @@ public class ReadOnlyNavigationIT extend
         Assert.assertNotNull("folder not found: " + path, folder);
 
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<CmisObject> pl = folder.getChildren();
+        ItemIterable<CmisObject> pl = folder.getChildren();
         Assert.assertNotNull(pl);
 
         for (CmisObject o : pl) {
@@ -192,7 +192,7 @@ public class ReadOnlyNavigationIT extend
         Assert.assertNotNull("folder not found: " + path, folder);
 
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<CmisObject> pl = folder.getChildren();
+        ItemIterable<CmisObject> pl = folder.getChildren();
         Assert.assertNotNull(pl);
 
         CmisObject firstObject = pl.iterator().next();

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyTypeIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyTypeIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyTypeIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/ReadOnlyTypeIT.java Wed May  5 08:40:31 2010
@@ -25,7 +25,7 @@ import junit.framework.Assert;
 import org.apache.chemistry.opencmis.client.api.DocumentType;
 import org.apache.chemistry.opencmis.client.api.FolderType;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.PolicyType;
 import org.apache.chemistry.opencmis.client.api.RelationshipType;
 import org.apache.chemistry.opencmis.client.api.Tree; //import org.apache.chemistry.opencmis.client.api.util.PagingList;
@@ -83,7 +83,7 @@ public class ReadOnlyTypeIT extends Abst
         ObjectType otd = this.session.getTypeDefinition(ObjectType.DOCUMENT_BASETYPE_ID);
         Assert.assertNotNull(otd);
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
+        ItemIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
         Assert.assertNotNull(pc);
 
         for (ObjectType ot1 : pc) {
@@ -97,10 +97,10 @@ public class ReadOnlyTypeIT extends Abst
         ObjectType otd = this.session.getTypeDefinition(ObjectType.DOCUMENT_BASETYPE_ID);
         Assert.assertNotNull(otd);
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
+        ItemIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
         Assert.assertNotNull(pc);
 
-        PagingIterable<ObjectType> pcc = pc.skipTo(2).getPage(2); 
+        ItemIterable<ObjectType> pcc = pc.skipTo(2).getPage(2); 
         for (ObjectType ot1 : pcc) {
             ObjectType ot2 = this.session.getTypeDefinition(ot1.getId());
             Assert.assertEquals(ot1.getId(), ot2.getId());
@@ -112,7 +112,7 @@ public class ReadOnlyTypeIT extends Abst
         ObjectType otd = this.session.getTypeDefinition(ObjectType.FOLDER_BASETYPE_ID);
         Assert.assertNotNull(otd);
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
+        ItemIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
         Assert.assertNotNull(pc);
 
         for (ObjectType ot1 : pc) {
@@ -126,10 +126,10 @@ public class ReadOnlyTypeIT extends Abst
         ObjectType otd = this.session.getTypeDefinition(ObjectType.FOLDER_BASETYPE_ID);
         Assert.assertNotNull(otd);
         this.session.getDefaultContext().setMaxItemsPerPage(2);
-        PagingIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
+        ItemIterable<ObjectType> pc = this.session.getTypeChildren(otd.getId(), true);
         Assert.assertNotNull(pc);
 
-        PagingIterable<ObjectType> pcc = pc.skipTo(0).getPage(2); 
+        ItemIterable<ObjectType> pcc = pc.skipTo(0).getPage(2); 
         for (ObjectType ot1 : pcc) {
             ObjectType ot2 = this.session.getTypeDefinition(ot1.getId());
             Assert.assertEquals(ot1, ot2);

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectRelationIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectRelationIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectRelationIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectRelationIT.java Wed May  5 08:40:31 2010
@@ -27,7 +27,7 @@ import java.util.Map;
 import org.apache.chemistry.opencmis.client.api.Document;
 import org.apache.chemistry.opencmis.client.api.ObjectId;
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Relationship;
 import org.apache.chemistry.opencmis.commons.PropertyIds;
 import org.apache.chemistry.opencmis.commons.enums.RelationshipDirection;
@@ -56,7 +56,7 @@ public class WriteObjectRelationIT exten
         ObjectId id = this.session.createRelationship(properties, null, null, null);
 
         ObjectType ot = document1.getType();
-        PagingIterable<Relationship> relations = document1.getRelationships(true, RelationshipDirection.EITHER, ot,
+        ItemIterable<Relationship> relations = document1.getRelationships(true, RelationshipDirection.EITHER, ot,
                 this.session.getDefaultContext());
         for (Relationship r : relations) {
             assertNotNull(r);

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectVersionIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectVersionIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectVersionIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/runtime/WriteObjectVersionIT.java Wed May  5 08:40:31 2010
@@ -25,7 +25,7 @@ import org.apache.chemistry.opencmis.cli
 import org.apache.chemistry.opencmis.client.api.DocumentType;
 import org.apache.chemistry.opencmis.client.api.Folder;
 import org.apache.chemistry.opencmis.client.api.ObjectId;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -52,7 +52,7 @@ public class WriteObjectVersionIT extend
         /* get all verchecked out docs which should be exactly one or zero */
         Folder f = this.session.getRootFolder();
         assertNotNull(f);
-        PagingIterable<Document> pi = f.getCheckedOutDocs();
+        ItemIterable<Document> pi = f.getCheckedOutDocs();
         assertNotNull(pi);
 
         for (Document d : pi) {
@@ -69,10 +69,10 @@ public class WriteObjectVersionIT extend
         /* get all verchecked out docs which should be exactly one or zero */
         Folder f = this.session.getRootFolder();
         assertNotNull(f);
-        PagingIterable<Document> pi = f.getCheckedOutDocs();
+        ItemIterable<Document> pi = f.getCheckedOutDocs();
         assertNotNull(pi);
         // test skipTo and getPage
-        PagingIterable<Document> pii = pi.skipTo(2).getPage(2);
+        ItemIterable<Document> pii = pi.skipTo(2).getPage(2);
         for (Document d : pii) {
             assertNotNull(d);
             assertEquals(this.checkdOutId, d.getId());

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/sample/AbstractSampleIT.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/sample/AbstractSampleIT.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/sample/AbstractSampleIT.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-test/chemistry-opencmis-test-fit/src/test/java/org/apache/chemistry/opencmis/fit/sample/AbstractSampleIT.java Wed May  5 08:40:31 2010
@@ -27,7 +27,7 @@ import static org.junit.Assert.assertTru
 import java.util.List;
 
 import org.apache.chemistry.opencmis.client.api.ObjectType;
-import org.apache.chemistry.opencmis.client.api.PagingIterable;
+import org.apache.chemistry.opencmis.client.api.ItemIterable;
 import org.apache.chemistry.opencmis.client.api.Session;
 import org.apache.chemistry.opencmis.client.api.Tree;
 import org.apache.chemistry.opencmis.commons.api.RepositoryInfo;
@@ -103,7 +103,7 @@ public abstract class AbstractSampleIT {
         checkBaseType(folderBaseId, BaseTypeId.CMIS_FOLDER, folderType);
 
         // get base types via getTypesChildren
-        PagingIterable<ObjectType> baseTypes = getSession().getTypeChildren(null, true);
+        ItemIterable<ObjectType> baseTypes = getSession().getTypeChildren(null, true);
         assertNotNull(baseTypes);
 
         boolean hasDocumentBaseType = false;
--- incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/PagingIterator.java (original)
+++ incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java Wed May  5 08:40:31 2010
@@ -25,7 +25,7 @@ import java.util.Iterator;
  * 
  * @param <T>
  */
-public interface PagingIterator<T> extends Iterator<T> {
+public interface ItemIterator<T> extends Iterator<T> {
 
     /**
      * Returns the current position within the CMIS collection.
@@ -35,11 +35,11 @@ public interface PagingIterator<T> exten
     long getPosition();
 
     /**
      * Returns the number of items fetched for the current page.
      * 
      * @return number of items for currently fetched page
      */
-    long getPageNumItems();
+    long getCurrentCollectionNumItems();
     
     /**
      * Returns whether the repository contains additional items beyond the page of

Propchange: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ItemIterator.java
------------------------------------------------------------------------------
    svn:eol-style = native
@@ -35,11 +35,11 @@ public interface PagingIterator<T> exten
 
     /**
-     * Returns the number of items fetched for the current page.
+     * Returns the number of items fetched for the current collection.
      * 
@@ -35,11 +35,11 @@ public interface PagingIterator<T> exten
      * 
-     * @return number of items for currently fetched page
+     * @return number of items for currently fetched collection
      */

Modified: incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ObjectType.java
URL: http://svn.apache.org/viewvc/incubator/chemistry/opencmis/trunk/chemistry-opencmis-client/chemistry-opencmis-client-api/src/main/java/org/apache/chemistry/opencmis/client/api/ObjectType.java?rev=941202&r1=941201&r2=941202&view=diff
==============================================================================